# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from . import utilities, tables

class Volume(pulumi.CustomResource):
    """
    Creates and destroys a volume in Docker. This can be used alongside
    [docker\_container](https://www.terraform.io/docs/providers/docker/r/container.html)
    to prepare volumes that can be shared across containers.
    """
    def __init__(__self__, __name__, __opts__=None, driver=None, driver_opts=None, labels=None, name=None):
        """Create a Volume resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['driver'] = driver

        __props__['driver_opts'] = driver_opts

        __props__['labels'] = labels

        __props__['name'] = name

        __props__['mountpoint'] = None

        super(Volume, __self__).__init__(
            'docker:index/volume:Volume',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

